sqltriples.SingleResults

Module sqltriples :: Class SingleResults |
[show private | hide private]
[frames | no frames]

## Class SingleResults

    Query --+
            |
      Results --+
                |
               SingleResults

Known Subclasses:
  `Objects`, `Predicates`, `Subjects`

A class representing a selection of single value results.

Method Summary
| `_execute(self)`
Inherited from Results
| ``__init__`(self, store, pattern, fn, ordering, limit)` Initialise the results object with the given 'store', 'pattern', optional 'ordering' description and optional 'limit' criteria.
| ``_apply_function`(self, fn, column)`
| ``_get_order_column`(self, index)`
| ``_get_order_extent`(self)`
| ``_get_query`(self, select_clause, index, constraints)` Build the query conditions and return a usable query which starts with the supplied 'select_clause' and which uses the given table 'index' number as qualifier.
Inherited from Query
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`
| ``get_child_query`(self, index)` Obtain the query clause and values (as a 2-tuple) which links this object's query to a parent query.
| ``_ensure`(self)`

Generated by Epydoc 2.1 on Fri Mar 31 17:48:37 2006 | http://epydoc.sf.net